@@ -202,9 +202,9 @@ def generate_testcase_list_by_csv(file_name, row, is_ui_testcase, tag_name=''):
                 class_name = py_file_name.split(".")[0].split(os.sep)[-1]
                 # class_name = "".join(class_name[:1].upper() + class_name[1:]) # todo: 讨论是否需要把clasName首字母转成大写？
                 if is_ui_testcase:
-                    new_file_lines.append("\n\n\nclass %s_%s(UITestCase):\n\n" % (class_name, row["id"]))
+                    new_file_lines.append("\n\n\nclass %s_%s(UITestCase):\n" % (class_name, row["id"]))
                 else:
-                    new_file_lines.append("\n\n\nclass %s_%s(APITestCase):\n\n" % (class_name, row["id"]))
+                    new_file_lines.append("\n\n\nclass %s_%s(APITestCase):\n" % (class_name, row["id"]))
                 new_file_lines.append('    tag = "%s, %s"\n\n' % (class_name, tag_name))
                 param_list = line.replace(" ", "").split("self,")[1].split(")")[0].split(",")
                 line = "    def run_test(self):"
@@ -221,6 +221,7 @@ def generate_testcase_list_by_csv(file_name, row, is_ui_testcase, tag_name=''):
 
             i += 1
 
+
     with open(file_name.split(".")[0] + "_case_list_auto_generated_by_csv.py", "a") as f:
         f.writelines(new_file_lines)
 
@@ -361,7 +362,7 @@ def auto_generate_testcase_list_from_csv(call_by_doctor=False):
                                 with open(PROJECT_INFO.project_path + os.sep + directory_path + os.sep +
                                           file_name.split(".")[
                                               0] + "_case_list_auto_generated_by_csv.py", "a") as f:
-                                    f.write("from lintest.ui_testcase import UITestCase\n")
+                                    f.write("from lintest.ui_testcase import UITestCase")
                                 break
 
                     if not is_ui_testcase:
@@ -369,7 +370,7 @@ def auto_generate_testcase_list_from_csv(call_by_doctor=False):
                         with open(PROJECT_INFO.project_path + os.sep + directory_path + os.sep +
                                   file_name.split(".")[
                                       0] + "_case_list_auto_generated_by_csv.py", "a") as f:
-                            f.write("from lintest.api_testcase import APITestCase\n")
+                            f.write("from lintest.api_testcase import APITestCase")
 
                     csv_file_full_path = PROJECT_INFO.project_path + os.sep + directory_path + os.sep + \
                                          file_name.split('.')[0] + ".csv"
