@@ -197,11 +197,30 @@ class Reporter(object):
                     %s
                     %s
                 </head>
+                
                 <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.2.0/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-gH2yIJqKdNHPEq0n4Mqa/HGKIhSkIHeL5AyhkYV8i59U5AR6csBvApHHNl/vI1Bx" crossorigin="anonymous">
                 <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.2.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-A3rJD856KowSb7dwlZdYEkO39Gagi7vIsF0jrRAoQmDKKtQBHUuLZ9AsSv4jD4Xa" crossorigin="anonymous"></script>
                 <script type="text/javascript" src="https://cdn.jsdelivr.net/clipboard.js/1.5.12/clipboard.min.js"></script>
                 <script type="text/javascript" src="https://cdn.jsdelivr.net/npm/echarts@5.0.2/dist/echarts.min.js"></script>
                 
+                <style>
+                .tooltip-inner {
+                  max-width: 280px;
+                  color: whitesmoke;
+                  text-align: right;
+                  text-decoration: none;
+                  background-color: darkcyan;
+                  border-radius: 4px;
+                }
+                .tooltip-arrow {
+                  position: absolute;
+                  width: 0;
+                  height: 0;
+                  border-color: darkcyan;
+                  border-style: solid;
+                }
+                </style>
+                
             """ % (
                 css,
                 java_script_code_for_filter,
@@ -255,7 +274,7 @@ class Reporter(object):
                             </tr>
                             <tr>
                                 <th>Test Framework</th>
-                                <td align='center'>lintest %s</td>
+                                <td align='center'><a target="_blank" href="https://plugins.jetbrains.com/plugin/19712-lintest/versions">lintest %s</a></td>
                             </tr>
                         </table>
                     </td>
@@ -293,7 +312,7 @@ class Reporter(object):
             <br>
             <table border='0' align='center' width='950'>
                 <tr>
-                    <td width='285'><font style='color: black; font-size: 18; margin-left: -30'>Filter TestCases By Package: </font></td>
+                    <td width='285'><font style='color: black; font-size: 18; margin-left: -30'>Filter By Package: </font></td>
                     <td>
             """
             report_file_handler.write(html_drop_down_list)
@@ -303,7 +322,7 @@ class Reporter(object):
                 all_testcases_package_list.append(testcase)
 
             all_testcases_package_list.sort()
-            report_file_handler.write("<select id=\"testcase_tag\" onchange=\"changeTag()\">")
+            report_file_handler.write("<select class='form-select' style='margin-left: -150px; overflow: hidden; text-overflow: ellipsis; width: 600;' id=\"testcase_tag\" onchange=\"changeTag()\">")
             for testcase in all_testcases_package_list:
                 report_file_handler.write("<option value='%s'>" % testcase)
                 report_file_handler.write("%s" % testcase)
@@ -408,7 +427,7 @@ class Reporter(object):
                     if failed_testcase.rerun_tag == 0:
                         try:
                             report_file_handler.write(
-                                "<a title='Click to see the log detail' href='%s'><font style='color: red'> Log</font></a>" %
+                                "<a target='_blank' style='white-space: nowrap;' data-bs-toggle='tooltip' data-bs-placement='right' title='Click to see the log detail' href='%s'><font style='color: red'> Log</font></a>" %
                                 failed_testcase.log_file_path)
                         except BaseException:
                             print(traceback.format_exc())
@@ -416,7 +435,7 @@ class Reporter(object):
                         try:
                             if isinstance(failed_testcase, UITestCase):
                                 report_file_handler.write(
-                                    "<a title='Screenshot' href='%s'> <font color='#DC3912'> - Screenshot</font> </a>" %
+                                    "<a target='_blank' style='white-space: nowrap;' data-bs-toggle='tooltip' data-bs-placement='right' title='click to see the Screenshot' href='%s'> <font color='#DC3912'> - Screenshot</font> </a>" %
                                     failed_testcase.screenshot)
                         except BaseException:
                             print(traceback.format_exc())
@@ -424,7 +443,7 @@ class Reporter(object):
                     elif failed_testcase.rerun_tag == 1:
                         try:
                             report_file_handler.write(
-                                "<a title='ReRun_Log' href='%s'> <font color='#DC3912'> | ReRun_Log</font> </a>" %
+                                "<a target='_blank' style='white-space: nowrap;' data-bs-toggle='tooltip' data-bs-placement='right' title='Click to see the ReRun_Log detail' href='%s'> <font color='#DC3912'> | ReRun_Log</font> </a>" %
                                 failed_testcase.log_file_path)
                         except BaseException:
                             print(traceback.format_exc())
@@ -432,7 +451,7 @@ class Reporter(object):
                         try:
                             if isinstance(failed_testcase, UITestCase):
                                 report_file_handler.write(
-                                    "<a title='ReRun_Screenshot' href='%s'> <font color='#DC3912'> - ReRun_Screenshot</font> </a>" %
+                                    "<a target='_blank' style='white-space: nowrap;' data-bs-toggle='tooltip' data-bs-placement='right' title='Click to see the ReRun_Screenshot' href='%s'> <font color='#DC3912'> - ReRun_Screenshot</font> </a>" %
                                     failed_testcase.rerun_screenshot)
                         except BaseException:
                             print(traceback.format_exc())
@@ -509,7 +528,7 @@ class Reporter(object):
 
                     try:
                         report_file_handler.write(
-                            "<a title='Click to show log detail' href='%s'>        <font color='#3366CC'>&nbsp;&nbsp;Log</font> </a>" %
+                            "<a style='white-space: nowrap;' data-bs-toggle='tooltip' data-bs-placement='right' title='Click to see log detail' href='%s'>   <font color='#3366CC'>&nbsp;&nbsp;Log</font> </a>" %
                             passed_testcase.log_file_path)
                     except BaseException:
                         print(traceback.format_exc())
@@ -616,6 +635,12 @@ class Reporter(object):
                     };
 
                     option && myChart.setOption(option);
+                    
+                    var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'))
+                    var tooltipList = tooltipTriggerList.map(function (tooltipTriggerEl) {
+                      return new bootstrap.Tooltip(tooltipTriggerEl)
+                    })
+                    
             </script>
                                 
                    """ % (len(passed_cases), failed_cases_count)
