@@ -90,7 +90,8 @@ class LoggedRequests:
             # 直接调用 开源 requests
             return requests.get(url, params, **kwargs)
 
-        self.logger.info(os.linesep + os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> GET Start:")
+        self.logger.info(
+            os.linesep + os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> GET Start:")
         self.logger.info(os.linesep + "---------------- URL: " + url)
 
         if params is not None:
@@ -99,22 +100,25 @@ class LoggedRequests:
 
         if len(kwargs.keys()) > 0:
             self.logger.info(os.linesep + "-------------- kwargs:")
-            self.logger.info(os.linesep + self.pformat(kwargs))
+            self.logger.info(os.linesep + json_func.dumps(kwargs, indent=2))
 
         # call requests.get()
         response = requests.get(url, params, **kwargs)
 
-        self.logger.info(os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< GET Response:")
+        self.logger.info(
+            os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< GET Response:")
         self.logger.info(response)
 
         # todo
         if response.status_code == 200:
             try:
-                self.logger.info(self.pformat(response.json()))
+                # self.logger.info(self.pformat(response.json()))
+                self.logger.info(os.linesep + json_func.dumps(response.json(), ensure_ascii=False, indent=2))
             except BaseException:
                 return response
 
-        self.logger.info(os.linesep + "========================= GET DONE =========================" + os.linesep + os.linesep)
+        self.logger.info(
+            os.linesep + "========================= GET DONE =========================" + os.linesep + os.linesep)
 
         return response
 
@@ -154,11 +158,12 @@ class LoggedRequests:
             # 直接调用 开源 requests
             return requests.post(url, data, json, **kwargs)
 
-        self.logger.info(os.linesep + os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> POST Start:")
+        self.logger.info(
+            os.linesep + os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> POST Start:")
         self.logger.info(os.linesep + "------------ URL: " + url)
 
         if data is not None:
-            self.logger.info(os.linesep + "------------ data start:")
+            self.logger.info(os.linesep + os.linesep + "------------ post data:")
 
             # # todo: headers type
             # if kwargs['headers']['Content-Type'] == 'application/x-www-form-urlencoded':
@@ -168,30 +173,33 @@ class LoggedRequests:
 
             try:
                 # 此处省去各种判断逻辑, 如果 json.loads()报错，则直接 记录原始data
-                self.logger.info(os.linesep + self.pformat(json_func.loads(data)))
+                # self.logger.info(os.linesep + self.pformat(json_func.loads(data)))
+                self.logger.info(os.linesep + json_func.dumps(json_func.loads(data), ensure_ascii=False, indent=2))
             except BaseException:
                 self.logger.info(os.linesep + self.pformat(data))
 
-            self.logger.info(os.linesep + "------------ data end -------" + os.linesep)
+            # self.logger.info(os.linesep + "------------ data end -------" + os.linesep)
 
         if json is not None:
-            self.logger.info(os.linesep + "------------ json:")
-            self.logger.info(os.linesep + self.pformat(json))
+            self.logger.info(os.linesep + os.linesep + "------------ json:")
+            self.logger.info(os.linesep + json_func.dumps(json, ensure_ascii=False, indent=2))
 
         if len(kwargs.keys()) > 0:
-            self.logger.info(os.linesep + "------------ kwargs:")
-            self.logger.info(os.linesep + self.pformat(kwargs))
+            self.logger.info(os.linesep + os.linesep + "------------ kwargs:")
+            self.logger.info(os.linesep + json_func.dumps(kwargs, ensure_ascii=False, indent=2))
 
         # call requests.post()
         response = requests.post(url, data, json, **kwargs)
 
-        self.logger.info(os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< POST Response:")
+        self.logger.info(
+            os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< POST Response:")
         self.logger.info(response)
 
         # todo
         if response.status_code == 200:
             try:
-                self.logger.info(os.linesep + self.pformat(response.json()))
+                # dumps()方法中的 indent参数 如果 不为空 则会自动format输出结果
+                self.logger.info(os.linesep + json_func.dumps(response.json(), ensure_ascii=False, indent=2))
             except BaseException:
                 self.logger.info(response.__dict__)
                 return response
@@ -224,7 +232,8 @@ class LoggedRequests:
             # 直接调用 开源 requests
             return requests.put(url, data, **kwargs)
 
-        self.logger.info(os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> PUT Start:")
+        self.logger.info(
+            os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> PUT Start:")
         self.logger.info(os.linesep + "-------------- URL: " + url)
 
         if data is not None:
@@ -234,21 +243,21 @@ class LoggedRequests:
             except BaseException:
                 self.logger.info(os.linesep + self.pformat(data))
 
-
         if len(kwargs.keys()) > 0:
             self.logger.info(os.linesep + "------------ kwargs:")
-            self.logger.info(os.linesep + self.pformat(kwargs))
+            self.logger.info(os.linesep + json_func.dumps(kwargs,ensure_ascii=False, indent=2))
 
         # call requests.put()
         response = requests.put(url, data, **kwargs)
 
-        self.logger.info(os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< PUT Response:")
+        self.logger.info(
+            os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< PUT Response:")
         self.logger.info(response)
 
         # todo
         if response.status_code == 200:
             try:
-                self.logger.info(os.linesep + self.pformat(response.json()))
+                self.logger.info(os.linesep + json_func.dumps(response.json(), ensure_ascii=False, indent=2))
             except BaseException:
                 return response
 
@@ -280,26 +289,29 @@ class LoggedRequests:
             # 直接调用 开源 requests
             return requests.delete(url, **kwargs)
 
-        self.logger.info(os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> DELETE Start:")
+        self.logger.info(
+            os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> DELETE Start:")
         self.logger.info(os.linesep + "--------------- URL: " + url)
 
         if len(kwargs.keys()) > 0:
             self.logger.info(os.linesep + "------------ kwargs:")
-            self.logger.info(os.linesep + self.pformat(kwargs))
+            self.logger.info(os.linesep + json_func.dumps(kwargs,ensure_ascii=False, indent=2))
 
         # call requests.delete()
         response = requests.delete(url, **kwargs)
 
-        self.logger.info(os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< DELETE Response:")
+        self.logger.info(
+            os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< DELETE Response:")
         self.logger.info(response)
 
         # todo
         if response.status_code == 200:
             try:
-                self.logger.info(os.linesep + self.pformat(response.json()))
+                self.logger.info(os.linesep + json_func.dumps(response.json(), ensure_ascii=False, indent=2))
             except BaseException:
                 return response
 
-        self.logger.info(os.linesep + "========================= DELETE DONE =========================" + os.linesep + os.linesep)
+        self.logger.info(
+            os.linesep + "========================= DELETE DONE =========================" + os.linesep + os.linesep)
 
         return response
